WebhookAuth

Struct WebhookAuth 

pub struct WebhookAuth(/* private fields */);
The unique token authorisation for the webhook.

Each monitored repository has it’s own unique token, and it is different each time git-next runs.

Implementations

Source

impl WebhookAuth

pub fn new(value: impl Into<Ulid>) -> Self

pub fn peel(self) -> Ulid

Source

impl WebhookAuth

pub fn try_new(authorisation: &str) -> Result<Self, DecodeError>

Parses the authorisation string as a Ulid to create a WebhookAuth.

Errors

Will return an Err if the authorisation string is not a valid Ulid.

pub fn generate() -> Self

pub fn header_value(&self) -> String

Methods from Deref<Target = Ulid>

pub fn datetime(&self) -> SystemTime

Gets the datetime of when this Ulid was created accurate to 1ms

Example
use std::time::{SystemTime, Duration};
use ulid::Ulid;

let dt = SystemTime::now();
let ulid = Ulid::from_datetime(dt);

assert!(
    dt + Duration::from_millis(1) >= ulid.datetime()
    && dt - Duration::from_millis(1) <= ulid.datetime()
);
pub const TIME_BITS: u8 = 48

pub const RAND_BITS: u8 = 80

pub fn timestamp_ms(&self) -> u64

Gets the timestamp section of this ulid

Example
use std::time::{SystemTime, Duration};
use ulid::Ulid;

let dt = SystemTime::now();
let ulid = Ulid::from_datetime(dt);

assert_eq!(u128::from(ulid.timestamp_ms()), dt.duration_since(SystemTime::UNIX_EPOCH).unwrap_or(Duration::ZERO).as_millis());
pub fn random(&self) -> u128

Gets the random section of this ulid

Example
use ulid::Ulid;

let text = "01D39ZY06FGSCTVN4T2V9PKHFZ";
let ulid = Ulid::from_string(text).unwrap();
let ulid_next = ulid.increment().unwrap();

assert_eq!(ulid.random() + 1, ulid_next.random());
pub fn to_str<'buf>( &self, buf: &'buf mut [u8], ) -> Result<&'buf mut str, EncodeError>

👎Deprecated since 1.2.0:

Use the infallible array_to_str instead.

Creates a Crockford Base32 encoded string that represents this Ulid

Example
use ulid::Ulid;

let text = "01D39ZY06FGSCTVN4T2V9PKHFZ";
let ulid = Ulid::from_string(text).unwrap();

let mut buf = [0; ulid::ULID_LEN];
let new_text = ulid.to_str(&mut buf).unwrap();

assert_eq!(new_text, text);
pub fn array_to_str<'buf>(&self, buf: &'buf mut [u8; 26]) -> &'buf mut str

Creates a Crockford Base32 encoded string that represents this Ulid

Example
use ulid::Ulid;

let text = "01D39ZY06FGSCTVN4T2V9PKHFZ";
let ulid = Ulid::from_string(text).unwrap();

let mut buf = [0; ulid::ULID_LEN];
let new_text = ulid.array_to_str(&mut buf);

assert_eq!(new_text, text);
pub fn to_string(&self) -> String

Creates a Crockford Base32 encoded string that represents this Ulid

Example
use ulid::Ulid;

let text = "01D39ZY06FGSCTVN4T2V9PKHFZ";
let ulid = Ulid::from_string(text).unwrap();

assert_eq!(&ulid.to_string(), text);
pub fn is_nil(&self) -> bool

Test if the Ulid is nil

Example
use ulid::Ulid;

let ulid = Ulid::new();
assert!(!ulid.is_nil());

let nil = Ulid::nil();
assert!(nil.is_nil());
pub fn increment(&self) -> Option<Ulid>

Increment the random number, make sure that the ts millis stays the same

pub fn to_bytes(&self) -> [u8; 16]

Returns the bytes of the Ulid in big-endian order.

Example
use ulid::Ulid;

let text = "7ZZZZZZZZZZZZZZZZZZZZZZZZZ";
let ulid = Ulid::from_string(text).unwrap();

assert_eq!(ulid.to_bytes(), [0xFF; 16]);